@@ -1,5 +1,7 @@
 package mymm;
 
+use strict;
+use warnings;
 use ExtUtils::MakeMaker;
 
 sub myWriteMakefile
